@@ -11,7 +11,7 @@ except ImportError:
     argparse = None
 
 
-__version__ = '0.5.1'
+__version__ = '0.5.2'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
@@ -172,8 +172,11 @@ class CompletionGenerator(object):
                     metavar = "::%s:(%s):" % (action.metavar, " ".join(metas))
                 else:
                     metavar = "::%s:_files" % action.metavar
+            elif action.choices and self.parser_type == 'argparse':
+                metavar = ":::(%s):" % (" ".join(action.choices))
             else:
                 metavar = ""
+
             if self.parser_type == 'optparse':
                 opts = [i for i in action._long_opts]
                 opts += [i for i in action._short_opts]
@@ -403,9 +406,7 @@ class HelpParser(object):
                 longopt = optlist[0]
                 shortopt = optlist[2]
                 metavar = optlist[1][:-1]
-                if len(line) < helpstring_offset:
-                    help_string = ""
-                elif line[helpstring_offset - 1] is ' ':
+                if len(line) >= helpstring_offset and line[helpstring_offset - 1] is ' ':
                     help_string = line[helpstring_offset:]
                 else:
                     help_string = ""
@@ -420,16 +421,12 @@ class HelpParser(object):
                 optlist = line.split()
                 longopt = optlist[0][:-1]
                 shortopt = optlist[1]
-                if len(line) < helpstring_offset:
-                    help_string = ""
-                elif line[helpstring_offset - 1] is ' ':
+                if len(line) >= helpstring_offset and line[helpstring_offset - 1] is ' ':
                     help_string = line[helpstring_offset:]
                 else:
                     help_string = ""
-                option_list.append({'short': shortopt,
-                                    'long': longopt,
-                                    'metavar': None,
-                                    'help': help_string + ' '})
+                option_list.append({'short': shortopt, 'long': longopt,
+                                    'metavar': None, 'help': help_string + ' '})
                 option_cnt += 1
             elif line.find('--') < helpstring_offset and tmp[0][:2] == '--':
                 ## only long option
@@ -437,7 +434,10 @@ class HelpParser(object):
                 longopt_offset = len(longopt) + 2
                 metavar = None
                 ## check exist METAVAR
-                if line[longopt_offset] == ' ' and \
+                if longopt_offset == len(line):
+                    # only option value
+                    pass
+                elif line[longopt_offset] == ' ' and \
                    re.search('[a-zA-Z[{]', line[longopt_offset + 1]):
                     metavar = tmp[1]
                     longopt_offset += len(metavar) + 1
